@@ -12,8 +12,8 @@ import zipfile
 from pathlib import Path
 scripts_dir_path = Path(__file__).parents[1]
 sys.path.insert(0, str(scripts_dir_path))
-from pathlib import Path
 from EVMVerifier.certoraJobList import JobList
+from EVMVerifier.certoraExtensionInfo import ExtensionInfoWriter
 from Shared.certoraUtils import flush_stdout, get_package_and_version, check_results, remove_file, write_json_file, \
     BETA_PACKAGE_NAME
 from Shared.certoraUtils import get_certora_build_file, get_certora_verify_file, get_certora_config_dir
@@ -518,6 +518,8 @@ class CloudVerification:
 
         self.set_protocol_name_and_author(context)
 
+        self.vscode_extension_info_writer = ExtensionInfoWriter()
+
     def __set_url(self, url_attr: str, index: str, user_id: int, anonymousKey: str,
                   requested_resource: Optional[str] = None) -> None:
         """
@@ -809,6 +811,10 @@ class CloudVerification:
         job_list.add_job(
             self.runName, self.reportUrl, self.msg, self.context.domain, str(self.userId), self.anonymousKey)
 
+        # Generate a json file for the VS Code extension with the relevant url
+        self.vscode_extension_info_writer.add_field("verification_report_url", self.reportUrl)
+        self.vscode_extension_info_writer.write_file()
+
         if send_only:  # do not wait for results
             job_list.save_data()
             job_list.save_recent_jobs_to_path()
