@@ -22,7 +22,19 @@ context_logger = logging.getLogger("context")
 
 CLI_DOCUMENTATION_URL = 'https://docs.certora.com/en/latest/docs/prover/cli/options.html'
 
-def collect_jar_args(context: CertoraContext) -> List[str]:
+
+def escape_string(string: str) -> str:
+    """
+    enclose string with double quotes if the string contains char that is not alphanum
+    """
+    pattern = re.compile('^[0-9a-zA-Z]+$')
+    if bool(pattern.match(string)):
+        return string
+    else:
+        return f"\"{string}\""
+
+
+def __collect_jar_args(context: CertoraContext) -> List[str]:
     """
     construct the jar flags. For each attribute with non-empty value in the context, we check if a jar flag was
     declared for that attribute. The jar command is a list of strings the first string is the flag (jar_flag). If
@@ -42,7 +54,7 @@ def collect_jar_args(context: CertoraContext) -> List[str]:
             elif type(attr) is bool:
                 return_list.append('true')
             elif type(attr) is str:
-                return_list.append(attr)
+                return_list.append(escape_string(attr))
             else:
                 raise RuntimeError(f"{arg.name}: {arg.value.arg_type} - unknown arg type")
 
@@ -66,7 +78,7 @@ def get_local_run_cmd(context: CertoraContext) -> str:
         run_args.extend(['-cache', context.cache])
 
     if Util.is_new_api():
-        jar_args = collect_jar_args(context)
+        jar_args = __collect_jar_args(context)
         run_args.extend(jar_args)
     else:
         # DEPRECATED
@@ -262,8 +274,10 @@ def __alter_args_before_argparse(args_list: List[str]) -> None:
             if ',' in arg:
                 args_list[idx] = arg.replace(",", ", ")
                 arg = args_list[idx]
-            if len(arg) > 1 and arg[0] == "-" and arg[1] != "-":  # fixes a problem with --javaArgs -single_flag
-                args_list[idx] = " " + arg
+            pattern = r"^[\"\']*-[^-]"  # a string that starts 0 or more qoutes followed by a single hyphen
+            if re.match(pattern, arg):
+                arg = re.sub('-', " -", arg, count=1)
+                args_list[idx] = arg
 
 
 def pre_arg_fetching_checks(args_list: List[str]) -> None:
@@ -379,12 +393,19 @@ def setup_cache(context: CertoraContext) -> None:
                 if Util.is_new_api():
                     branch = context.prover_version if context.prover_version else ''
                     context.cache += f'-{context.server}-{branch}'
+                    is_installed, package, version = Util.get_package_and_version()
+                    if is_installed:
+                        context.cache += f'-{package}-{version}'
                     pass
                 else:
                     if context.cloud is not None:
                         context.cache += f'-cloud-{context.cloud}'
                     elif context.staging:
                         context.cache += f'-staging-{context.staging}'
+                    else:
+                        is_installed, package, version = Util.get_package_and_version()
+                        if is_installed:
+                            context.cache += f'-{package}-{version}'
                     context_logger.debug(f"setting cache key to {context.cache}")
 
 
