@@ -5,6 +5,8 @@ from abc import ABC, abstractmethod
 from enum import Enum
 import logging
 
+from Shared.certoraUtils import find_filename_in, get_certora_sources_dir
+
 ast_logger = logging.getLogger("ast")
 
 
@@ -308,7 +310,27 @@ class UserDefinedType(Type):
         self.canonical_name = canonical_name
         self.contract_name = contract_name
         self.reference = reference
-        self.canonical_id = f"{file}|{canonical_name}"
+        self.file_for_canonical_id = file
+
+    def generate_canonical_id(self) -> str:
+        """
+        We don't want canonical ids to contain absolute paths, because it can interfere with caching.
+        I.e. if the canonical_id contains a part of an absolute path, and then we run the same job
+        in a different machine (i.e. different user name), we'll get a failure to merge type descriptors
+        because that part of the string representing a user name is different.
+        This is absurd, so we try to resolve with respect to .certora_sources.
+        If not, we just take whatever we got from the constructor of the type.
+        Hopefully the lazy computation of the final canonical_id going to the part consumed by the
+        typechecker in the cloud is late enough so that the resolution actually succeeds.
+        Is it bullet-proof? Not at all - but works for now.
+        """
+        if self.file_for_canonical_id is None:  # happened in Vyper
+            return self.canonical_name
+
+        resolve_file = find_filename_in(get_certora_sources_dir(), self.file_for_canonical_id)
+        if resolve_file is None:
+            return f"{self.file_for_canonical_id}|{self.canonical_name}"
+        return f"{resolve_file}|{self.canonical_name}"
 
     @abstractmethod
     def as_dict(self) -> Dict[str, Any]:
@@ -363,7 +385,7 @@ class EnumType(UserDefinedType):
             "enumMembers": [{"name": x} for x in self.members],
             "containingContract": self.contract_name,  # null means it wasn't declared in a contract but at file-level
             "astId": self.reference,
-            "canonicalId": self.canonical_id
+            "canonicalId": self.generate_canonical_id()
         }
 
     def get_abi_canonical_string(self, is_library: bool) -> str:
@@ -428,7 +450,7 @@ class StructType(UserDefinedType):
             "containingContract": self.contract_name,
             # ^ null means it wasn't declared in a contract but at file-level (is this possible for structs?)
             "astId": self.reference,
-            "canonicalId": self.canonical_id,
+            "canonicalId": self.generate_canonical_id(),
         }
 
     def default_location(self) -> 'TypeLocation':
@@ -476,7 +498,7 @@ class UserDefinedValueType(UserDefinedType):
             "containingContract": self.contract_name,
             "valueTypeAliasedName": self.underlying.as_dict(),
             "astId": self.reference,
-            "canonicalId": self.canonical_id,
+            "canonicalId": self.generate_canonical_id(),
         }
 
     def get_abi_canonical_string(self, is_library: bool) -> str:
